/*
 * Generic support for opening files.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <fsserver/accessor.h>
#include <fsserver/directory_accessor.h>



/* An interface offering file opening support. */

class FileOpening
{
public:
    virtual bool accessing_directory(const char *path, flags_t flags, fileid_t fileid) = 0;

    virtual bool accessing_file(const char *path, flags_t flags, fileid_t fileid) = 0;

    virtual long get_fileid(const char *path, flags_t flags, fileid_t *fileid) = 0;

    virtual long make_accessor(const char *path, flags_t flags, fileid_t fileid,
                               Accessor **accessor) = 0;

    virtual long make_directory_accessor(const char *path, flags_t flags,
                                         fileid_t fileid,
                                         DirectoryAccessor **accessor) = 0;
};

// vim: tabstop=4 expandtab shiftwidth=4
